"use strict";
/* -------------------------------------------------------------------------------------------
 * Copyright (c) RedShift Development LLC
 * Licensed under the MIT license. See License.txt in the project root for license information
 * ---------------------------------------------------------------------------------------- */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NewServiceBridge = void 0;
const http_1 = require("http");
const buffer_1 = require("buffer");
const NewServiceBridge = (ipc) => {
    ipc.handle('rsipc-request', (_, name, method, data) => {
        return new Promise((resolve, reject) => {
            const opts = {
                socketPath: `\\\\.\\pipe\\${name}`,
                path: `${method}`,
                headers: {
                    'Content-Type': 'application/json',
                    'Content-Length': buffer_1.Buffer.byteLength(data),
                },
            };
            const req = http_1.request(opts, (res) => {
                // Reconstruct response from chunks
                const response = [];
                res.on('data', (chunk) => {
                    response.push(chunk);
                });
                res.on('end', () => {
                    resolve(response.join(''));
                });
            });
            req.on('error', (err) => {
                reject(err);
            });
            req.write(data);
            req.end();
        });
    });
};
exports.NewServiceBridge = NewServiceBridge;
//# sourceMappingURL=bridge.js.map