/* -------------------------------------------------------------------------------------------
 * Copyright (c) RedShift Development LLC
 * Licensed under the MIT license. See License.txt in the project root for license information
 * ---------------------------------------------------------------------------------------- */
import { request } from 'http';
import { Buffer } from 'buffer';
export const NewServiceBridge = (ipc) => {
    ipc.handle('rsipc-request', (_, name, method, data) => {
        return new Promise((resolve, reject) => {
            const opts = {
                socketPath: `\\\\.\\pipe\\${name}`,
                path: `${method}`,
                headers: {
                    'Content-Type': 'application/json',
                    'Content-Length': Buffer.byteLength(data),
                },
            };
            const req = request(opts, (res) => {
                // Reconstruct response from chunks
                const response = [];
                res.on('data', (chunk) => {
                    response.push(chunk);
                });
                res.on('end', () => {
                    resolve(response.join(''));
                });
            });
            req.on('error', (err) => {
                reject(err);
            });
            req.write(data);
            req.end();
        });
    });
};
//# sourceMappingURL=bridge.js.map